@@ -3,6 +3,7 @@ import os
 import re
 import jinja2
 import venv
+from subprocess import Popen
 from glasskit.uorm.models.meta import snake_case
 
 
@@ -70,6 +71,9 @@ def run_create(args):
     try:
         os.chdir(dirname)
         venv.create(args.venv, with_pip=True)
+        python_path = os.path.join(curr_dir, "venv/bin/pip3")
+        p = Popen([python_path, 'install', '-r', 'requirements.txt'])
+        p.wait()
     finally:
         os.chdir(curr_dir)
 
